@@ -1,13 +1,13 @@
 from .core import CanonMap
 from .services.db_mysql.config import CanonMapMySQLConfig
 from .services.db_mysql.core import CanonMapMySQLClient
-from .services.db_mysql.schemas import MatchEntityRequest, Field, FieldTransform
+from .services.db_mysql.schemas import EntityMappingRequest, EntityMappingResponse, SingleMappedEntity, TableField, FieldTransformType
 
 __all__ = [
     "CanonMap",
     "CanonMapMySQLConfig",
     "CanonMapMySQLClient",
-    "MatchEntityRequest",
-    "Field",
-    "FieldTransform",
+    "EntityMappingRequest",
+    "TableField",
+    "FieldTransformType",
 ]
\ No newline at end of file
