@@ -6,7 +6,7 @@ from pathlib import Path
 from typing import Union, Optional, List, Dict, Any
 
 from canonmap.services.db_mysql.adapters.connection import ConnectionManager
-from canonmap.services.db_mysql.schemas import Field, FieldTransform
+from canonmap.services.db_mysql.schemas import TableField, FieldTransformType
 from canonmap.services.db_mysql.adapters.cursor import get_cursor
 
 from canonmap.services.db_mysql.schemas import CreateDDLResponse # type: ignore
@@ -156,16 +156,16 @@ class TableManager:
 
 
     #########################################################
-    # Table Field Management
+    # Table TableField Management
     #########################################################
     def create_table_fields(
         self,
-        fields: list["Field"],
+        fields: list["TableField"],
         pk_field: str | None = None,
         batch_size: int = 10_000,
     ) -> dict[str, list[str]]:
         """
-        For each Field(table_name, field_name, field_transform) create a derived column:
+        For each TableField(table_name, field_name, field_transform) create a derived column:
         initialism  -> FIRST LETTERS ONLY (ABC)
         phonetic    -> Double Metaphone primary code
         soundex     -> MySQL SOUNDEX()
@@ -173,7 +173,7 @@ class TableManager:
         Returns: {table_name: [new_field_names]}
         """
         # Group/validate
-        by_table: dict[str, list[Field]] = {}
+        by_table: dict[str, list[TableField]] = {}
         for f in fields:
             kind = (f.field_transform or "").lower()
             if kind not in {"initialism", "phonetic", "soundex"}:
@@ -218,8 +218,8 @@ class TableManager:
                 cols = {r[0] for r in cursor.fetchall()}
 
             # Split work
-            sql_jobs: list[tuple[Field, str]] = []
-            py_jobs:  list[tuple[Field, str]] = []
+            sql_jobs: list[tuple[TableField, str]] = []
+            py_jobs:  list[tuple[TableField, str]] = []
 
             for f in flist:
                 if f.field_name not in cols:
@@ -232,7 +232,7 @@ class TableManager:
                     conn.commit()
                     cols.add(new_field)
 
-                if f.field_transform == FieldTransform.SOUNDEX:
+                if f.field_transform == FieldTransformType.SOUNDEX:
                     sql_jobs.append((f, new_field))
                 else:
                     py_jobs.append((f, new_field))
@@ -275,7 +275,7 @@ class TableManager:
                         row_map = dict(zip(colnames, row))
                         for f, new_field in py_jobs:
                             src_val = row_map[f.field_name]
-                            if f.field_transform == FieldTransform.INITIALISM:
+                            if f.field_transform == FieldTransformType.INITIALISM:
                                 transformed = to_initialism(src_val)
                             else:
                                 transformed = to_phonetic(src_val)
@@ -294,17 +294,17 @@ class TableManager:
         logger.info("✅ Finished create_table_fields.")
         return created
 
-    def drop_table_fields(self, fields: list["Field"]) -> dict[str, list[str]]:
+    def drop_table_fields(self, fields: list["TableField"]) -> dict[str, list[str]]:
         """
-        Drop the derived columns referenced by Field objects.
-        Uses Field.field_transform to infer the column name:
+        Drop the derived columns referenced by TableField objects.
+        Uses TableField.field_transform to infer the column name:
         new_col = f"{field_name}_{field_transform.lower()}"
         If field_transform is None, it will try to drop `field_name` directly.
 
         Returns: {table_name: [dropped_cols]}
         """
         # Group by table
-        by_table: dict[str, list[Field]] = {}
+        by_table: dict[str, list[TableField]] = {}
         for f in fields:
             by_table.setdefault(f.table_name, []).append(f)
 
